Struct ra_ap_proc_macro_api::msg::ExpandMacro[][src]

pub struct ExpandMacro {
    pub macro_body: FlatTree,
    pub macro_name: String,
    pub attributes: Option<FlatTree>,
    pub lib: PathBuf,
    pub env: Vec<(String, String)>,
}

Fields

macro_body: FlatTree

Argument of macro call.

In custom derive this will be a struct or enum; in attribute-like macro - underlying item; in function-like macro - the macro body.

macro_name: String

Name of macro to expand.

In custom derive this is the name of the derived trait (Serialize, Getters, etc.). In attribute-like and function-like macros - single name of macro itself (show_streams).

attributes: Option<FlatTree>

Possible attributes for the attribute-like macros.

lib: PathBufenv: Vec<(String, String)>

Environment variables to set during macro expansion.