Struct ra_ap_proc_macro_api::ProcMacroServer
source · pub struct ProcMacroServer { /* private fields */ }Expand description
A handle to an external process which load dylibs with macros (.so or .dll) and runs actual macro expansion functions.
Implementations
sourceimpl ProcMacroServer
impl ProcMacroServer
sourcepub fn spawn(
process_path: AbsPathBuf,
env: &FxHashMap<String, String>
) -> Result<ProcMacroServer>
pub fn spawn( process_path: AbsPathBuf, env: &FxHashMap<String, String> ) -> Result<ProcMacroServer>
Spawns an external process as the proc macro server and returns a client connected to it.
pub fn load_dylib( &self, dylib: MacroDylib ) -> Result<Vec<ProcMacro>, ServerError>